@@ -25,6 +25,7 @@ import warnings
 from luigi.target import FileSystem, FileSystemTarget, FileAlreadyExists
 import configuration
 import logging
+import getpass
 logger = logging.getLogger('luigi-interface')
 
 
@@ -54,11 +55,14 @@ def load_hadoop_cmd():
     return luigi.configuration.get_config().get('hadoop', 'command', 'hadoop')
 
 
-def tmppath(path=None):
+def tmppath(path=None, include_unix_username=True):
     """
     @param path: target path for which it is needed to generate temporary location
     @type path: str
+    @type include_unix_username: bool
     @rtype: str
+
+    Note that include_unix_username might work on windows too.
     """
     addon = "luigitemp-%08d" % random.randrange(1e9)
     temp_dir = tempfile.gettempdir()
@@ -90,6 +94,9 @@ def tmppath(path=None):
         #just return any random temporary location
         subdir = ''
 
+    if include_unix_username:
+        subdir = os.path.join(getpass.getuser(), subdir)
+
     return os.path.join(base_dir, subdir + addon)
 
 def list_path(path):
@@ -596,7 +603,8 @@ class HdfsAtomicWritePipe(luigi.format.OutputPipeProcessWrapper):
         super(HdfsAtomicWritePipe, self).__init__([load_hadoop_cmd(), 'fs', '-put', '-', self.tmppath])
 
     def abort(self):
-        print "Aborting %s('%s'). Removing temporary file '%s'" % (self.__class__.__name__, self.path, self.tmppath)
+        logger.info("Aborting %s('%s'). Removing temporary file '%s'",
+                self.__class__.__name__, self.path, self.tmppath)
         super(HdfsAtomicWritePipe, self).abort()
         remove(self.tmppath)
 
@@ -614,7 +622,8 @@ class HdfsAtomicWriteDirPipe(luigi.format.OutputPipeProcessWrapper):
         super(HdfsAtomicWriteDirPipe, self).__init__([load_hadoop_cmd(), 'fs', '-put', '-', self.datapath])
 
     def abort(self):
-        print "Aborting %s('%s'). Removing temporary dir '%s'" % (self.__class__.__name__, self.path, self.tmppath)
+        logger.info("Aborting %s('%s'). Removing temporary dir '%s'",
+                self.__class__.__name__, self.path, self.tmppath)
         super(HdfsAtomicWriteDirPipe, self).abort()
         remove(self.tmppath)
 
@@ -712,7 +721,7 @@ in luigi. Use target.path instead", stacklevel=2)
 
     @luigi.util.deprecate_kwarg('fail_if_exists', 'raise_if_exists', False)
     def move(self, path, fail_if_exists=False):
-        self.rename(path, fail_if_exists=fail_if_exists)
+        self.rename(path, raise_if_exists=fail_if_exists)
 
     def move_dir(self, path):
         # mkdir will fail if directory already exists, thereby ensuring atomicity
