@@ -374,8 +374,8 @@ class OptParseInterface(Interface):
             description = [param_name]
             if param.description:
                 description.append(param.description)
-            if param.has_default:
-                description.append(" [default: %s]" % (param.default,))
+            if param.has_value:
+                description.append(" [default: %s]" % (param.value,))
 
             if param.is_list:
                 action = "append"
